<?php

namespace FiloBlu\Flow\Model\Channel\In;

use Exception;

/**
 * Class Stock
 * @package FiloBlu\Flow\Model\Channel\In
 */
class Stock extends AbstractModel
{

    /**
     * @param $channelName
     * @return $this
     * @throws Exception
     */
    public function load($channelName)
    {
        $this->init($channelName);
        return $this;
    }

    /**
     * @param $data
     * @return bool
     * @throws Exception
     */
    public function insertData($data)
    {
        $parser = $this->getParser();

        if (($useMap = $this->getChannelConfig()->usesMap())) {
            if (!isset($this->map) || empty($this->map)) {
                throw  new Exception("Stock has option 'use map = yes' but no map is provided");
            }

            $this->map = $parser->map;
        }

        $check_mapping_count = $parser->checkMappingCount();

        $flow = $this->getFile()->getData('flow');
        $model = $this->objectManager->create("FiloBlu\Flow\Model\\{$flow}");

        if (!$model) {
            return false;
        }

        $model->setData('meta_file', $this->getFile()->getId());
        $model->setData('meta_processed', 0);

        foreach ($data as $field => $value) {

            // Have a json mapping?
            if ($useMap) {

                // Get the mapping
                $fieldMap = $this->map->get($field);
                // I need to skip this?
                if (!isset($fieldMap['skip'])) {
                    // Have a destination field? Set that as a 'to field'
                    if (isset($fieldMap['to']) && $fieldMap['to']) {
                        $to_field = $fieldMap['to'];
                        $model->setData($to_field, $value);
                        // Don't have a destination field but the check_mapping_count is off? Fallback to column name
                    } elseif (!$check_mapping_count) {
                        $model->setData($field, $value);
                    }
                }

                // No json mapping here
            } else {
                $model->setData($field, $value);
            }

        }

        if (!$model->getData('magazzino')) {
            $model->setData('magazzino', 'VEN');
        }

        $model->save();
    }

}
